@@ -10,13 +10,14 @@ from pyiron_base.generic.factory import PyironFactory
 from abc import ABC, abstractmethod
 from pyiron_base.job.jobtype import JobType
 from pyiron_base.job.generic import GenericJob
-from typing import Type
+from typing import Type, Dict, List, Union
 
 from pyiron_base.master.flexible import FlexibleMaster
 from pyiron_base.job.script import ScriptJob
 from pyiron_base.master.serial import SerialMasterBase
 from pyiron_base.table.datamining import TableJob
 from pyiron_base.generic.hdfio import ProjectHDFio
+from pyiron_base.state import state
 
 __author__ = "Liam Huber, Jan Janssen"
 __copyright__ = (
@@ -34,15 +35,25 @@ class JobFactoryCore(PyironFactory, ABC):
     def __init__(self, project: Project):
         self._project = project
 
-    def __dir__(self):
+    @property
+    @abstractmethod
+    def _job_class_dict(self) -> Dict:
+        pass
+
+    def __dir__(self) -> List:
         """
         Enable autocompletion by overwriting the __dir__() function.
         """
         return list(self._job_class_dict.keys())
 
-    def __getattr__(self, name):
+    def __getattr__(self, name) -> Type[GenericJob]:
         if name in self._job_class_dict.keys():
-            def wrapper(job_name, delete_existing_job=False, delete_aborted_job=False) -> Type[GenericJob]:
+
+            def wrapper(
+                job_name: str,
+                delete_existing_job: bool = False,
+                delete_aborted_job: bool = False,
+            ) -> GenericJob:
                 """
                 Create a job.
 
@@ -55,29 +66,61 @@ class JobFactoryCore(PyironFactory, ABC):
                     GenericJob: job object depending on the job_type selected
                 """
                 return JobType(
-                    class_name=self._job_class_dict[name],  # Pass the class directly, JobType can handle that
-                    project=ProjectHDFio(project=self._project.copy(), file_name=job_name),
+                    class_name=self._job_class_dict[
+                        name
+                    ],  # Pass the class directly, JobType can handle that
+                    project=ProjectHDFio(
+                        project=self._project.copy(), file_name=job_name
+                    ),
                     job_name=job_name,
                     job_class_dict=self._job_class_dict,
                     delete_existing_job=delete_existing_job,
-                    delete_aborted_job=delete_aborted_job
+                    delete_aborted_job=delete_aborted_job,
                 )
+
             return wrapper
         else:
             raise AttributeError("no job class named '{}' defined".format(name))
 
-    @property
-    @abstractmethod
-    def _job_class_dict(self):
-        pass
+    def __call__(
+        self,
+        job_type: Union[str, Type[GenericJob]],
+        job_name: str,
+        delete_existing_job: bool = False,
+        delete_aborted_job: bool = False,
+    ) -> GenericJob:
+        """
+        Create a job.
+
+        Args:
+            job_type (str|Type[GenericJob]): The job class to be instantiated, either the string from a known class, or
+                an actual class, e.g. in the case of custom user-made jobs.
+            job_name (str): name of the job.
+            delete_existing_job (bool): delete an existing job. (Default is False.)
+            delete_aborted_job (bool): delete an existing and aborted job. (Default is False.)
+
+        Returns:
+            GenericJob: job object depending on the job_type selected
+        """
+        job = JobType(
+            class_name=job_type,  # Pass the class directly, JobType can handle that
+            project=ProjectHDFio(project=self._project.copy(), file_name=job_name),
+            job_name=job_name,
+            job_class_dict=self._job_class_dict,
+            delete_existing_job=delete_existing_job,
+            delete_aborted_job=delete_aborted_job,
+        )
+        if state.settings.login_user is not None:
+            job.user = state.settings.login_user
+        return job
 
 
 class JobFactory(JobFactoryCore):
     @property
-    def _job_class_dict(self) -> dict:
+    def _job_class_dict(self) -> Dict:
         return {
             "FlexibleMaster": FlexibleMaster,
             "ScriptJob": ScriptJob,
             "SerialMasterBase": SerialMasterBase,
-            "TableJob": TableJob
+            "TableJob": TableJob,
         }
